Documentation
¶
Overview ¶
Package mysum implements an acme:service:summation, a demo service which sums (or subtracts) a given list of numbers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Model = resource.NewModel("acme", "demo", "mysum")
Model is the full model definition.
Functions ¶
This section is empty.
Types ¶
type Config ¶ added in v0.10.0
type Config struct {
Subtract bool `json:"subtract,omitempty"` // the omitempty defaults the bool to golang's default of false
// Embed TriviallyValidateConfig to make config validation a no-op. We will not check if any attributes exist
// or are set to anything in particular, and there will be no implicit dependencies.
// Config structs used in resource registration must implement Validate.
resource.TriviallyValidateConfig
}
Config is the sum model's config.
Click to show internal directories.
Click to hide internal directories.